Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(99)

Unified Diff: net/proxy/proxy_resolver_v8_tracing.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/proxy/proxy_resolver_v8_tracing.h
diff --git a/net/proxy/proxy_resolver_v8_tracing.h b/net/proxy/proxy_resolver_v8_tracing.h
index 6bca78bb64cb2e68d27f48690b373e93f9d7c90f..8ae04da0ff66ec57a0149627f3a4b0737a121a2e 100644
--- a/net/proxy/proxy_resolver_v8_tracing.h
+++ b/net/proxy/proxy_resolver_v8_tracing.h
@@ -38,9 +38,9 @@ class NET_EXPORT ProxyResolverV8Tracing {
// Returns a HostResolver to use for DNS resolution.
virtual HostResolver* GetHostResolver() = 0;
// Returns a BoundNetLog to be passed to the HostResolver returned by
// GetHostResolver().
- virtual BoundNetLog GetBoundNetLog() = 0;
+ virtual NetLogWithSource GetNetLogWithSource() = 0;
private:
DISALLOW_COPY_AND_ASSIGN(Bindings);
@@ -38,9 +38,9 @@ class NET_EXPORT ProxyResolverV8Tracing {
// Returns a HostResolver to use for DNS resolution.
virtual HostResolver* GetHostResolver() = 0;
- // Returns a BoundNetLog to be passed to the HostResolver returned by
+ // Returns a NetLogWithSource to be passed to the HostResolver returned by
// GetHostResolver().

Powered by Google App Engine
This is Rietveld 408576698